@@ -2,6 +2,7 @@
 #'
 #' @param .data A table of data.
 #' @param ... A selection of columns. If empty, all columns are selected.
+#' @param .logic boolean, either 'AND' or 'OR'. Logic for keeping NAs.
 #' @return A data frame.
 #' @examples
 #' library(dplyr)
@@ -12,7 +13,8 @@
 #' vars <- "y"
 #' df %>% keep_na(x, any_of(vars))
 #' @export
-keep_na <- function(.data, ...) {
+keep_na <- function(.data, ..., .logic = "AND") {
+  stopifnot(.logic %in% c("AND", "OR"))
   .data <- assert_df(.data)
   vars <- tidyselect::eval_select(rlang::expr(c(...)), .data)
   if (rlang::is_empty(vars)) {
@@ -21,6 +23,9 @@ keep_na <- function(.data, ...) {
     na_vars <- dplyr::select(.data, ...)
   }
   na_inds <- purrr::map(na_vars, ~which(is.na(.)))
-  common_na_inds <- purrr::reduce(na_inds, dplyr::intersect)
-  dplyr::slice(.data, common_na_inds)
+  lf <- switch(.logic,
+               "AND" = dplyr::intersect,
+               "OR" = c)
+  slice_inds <- unique(purrr::reduce(na_inds, lf))
+  dplyr::slice(.data, slice_inds)
 }
